# V1alpha1CronWorkflowStatus

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active** | [**list[IoK8sApiCoreV1ObjectReference]**](IoK8sApiCoreV1ObjectReference.md) | Active is a list of active workflows stemming from this CronWorkflow | [optional] 
**last_scheduled_time** | **datetime** | LastScheduleTime is the last time the CronWorkflow was scheduled | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


